use sea_orm::{EntityTrait, PaginatorTrait};
use sea_orm::ActiveValue::Set;
use domain::dto::feedback::FeedbackAdd;
use domain::entities::feedback;
use domain::entities::prelude::Feedback;
use library::db;
use library::resp::pageable::Pageable;
use library::resp::response::{ResOK, ResResult};

/// 获取反馈信息列表
pub async fn get_feedback_list_by_page(page: u64, page_size: u64) -> ResResult<ResOK<Pageable<feedback::Model>>> {
    let feedback_list = Feedback::find()
        .paginate(db!(), page_size)
        .fetch_page(page)
        .await
        .ok();
    if feedback_list.is_none() {
        tracing::error!("反馈信息为空");
        return Ok(ResOK(Some(Pageable::<feedback::Model>::empty())));
    }
    let total = get_feedback_count().await;
    Ok(ResOK(Some(Pageable::new(feedback_list.unwrap(), total))))
}

/// 获取反馈信息总数
async fn get_feedback_count() -> u64 {
    let count = Feedback::find().count(db!()).await.ok();
    if count.is_none() {
        tracing::error!("反馈信息为空");
        return 0;
    }
    count.unwrap()
}

/// 添加反馈信息
pub async fn add_feedback(req: FeedbackAdd) -> ResResult<ResOK<()>> {
    let now = chrono::Local::now().naive_local();

    let model = feedback::ActiveModel {
        user_id: Set(req.user_id.unwrap()),
        content: Set(req.content.unwrap()),
        created_at: Set(now),
        ..Default::default()
    };

    if let Err(err) = Feedback::insert(model).exec(db!()).await {
        tracing::error!(error = ?err, "添加反馈信息失败");
        return Err(library::resp::response::ResErr::ErrSystem(None));
    }

    Ok(ResOK(None))
}